package de.limited_dev.lil_judd.features.components.scrims;

import de.limited_dev.lil_judd.util.EmbeddedMessageHelper;
import de.limited_dev.lil_judd.util.TimeUtil;
import net.dv8tion.jda.api.entities.Guild;
import net.dv8tion.jda.api.entities.User;
import net.dv8tion.jda.api.entities.channel.concrete.TextChannel;

import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

public class GuildInQueue {
    private final Guild g;
    private GuildInQueue enemyGuildInQueue;
    private final TextChannel responseChannel;
    private final int div;
    private final List<User> users;
    private final long startedSearching;
    private long startedScrim;

    public GuildInQueue(Guild g, TextChannel responseChannel, int div, User u1, User u2, User u3, User u4){
        this.g = g;
        this.responseChannel = responseChannel;
        this.div = div;
        this.users = new CopyOnWriteArrayList<>(){{
            add(u1);
            add(u2);
            add(u3);
            add(u4);
        }};
        this.startedSearching = System.currentTimeMillis();
    }

    public void startScrimWith(GuildInQueue g2){
        this.enemyGuildInQueue = g2;
        this.startedScrim = System.currentTimeMillis();
        EmbeddedMessageHelper.sendSimpleOneLiner(this.g, this.responseChannel.getIdLong(), "Team found.", "A Scrim has been found!\nTime spent queuing: " + TimeUtil.getTimeFormatedRaw(this.startedScrim - this.startedSearching) + "\nYou will play against: " + this.enemyGuildInQueue.getGuild().getName() + "\n" +
                "Please communicate with the other team with /msgscrim <Msg>; end the scrim with /endscrim", this.enemyGuildInQueue.getGuild().getIconUrl(), 2);
    }

    public void endScrim(){
        EmbeddedMessageHelper.sendSimpleOneLiner(this.g, this.responseChannel.getIdLong(), "The Scrim has ended.", "The Scrim with " + this.enemyGuildInQueue.getGuild().getName() + " was ended.", this.enemyGuildInQueue.getGuild().getIconUrl());
    }


    public void sendMessageInResponseChannel(String msg, User u){
        if(u == null){
            EmbeddedMessageHelper.sendSimpleOneLiner(this.g, this.responseChannel.getIdLong(), "Info", "System >> " + msg, null);
            return;
        }
        EmbeddedMessageHelper.sendSimpleOneLiner(this.g, this.responseChannel.getIdLong(), "Message from " + this.enemyGuildInQueue.getGuild().getName(), u.getName() + "#" + u.getDiscriminator() + " >> " + msg, u.getAvatarUrl());
    }

    public boolean hasUserInIt(User u){
        return users.contains(u);
    }

    public List<User> getUsers() {
        return users;
    }

    public GuildInQueue getEnemy(){
        return this.enemyGuildInQueue;
    }

    public int getDiv(){
        return this.div;
    }

    public Guild getGuild() {
        return g;
    }

    public TextChannel getResponseChannel(){
        return this.responseChannel;
    }
}
